numerical_interactive_mip: Interactive mixed integer linear programming solver
==============================================================================

Description
-----------

Interactive mixed integer linear programming solver

License
-------

GNU General Public License (GPL) v2 or later

Upstream Contact
----------------

https://pypi.org/project/sage-numerical-interactive-mip/

